# Palimpsest Tools Catalog
This is a directory of tools we have for the palimpzest.

## Tools
For the pdf precessing tools, we have the following:
- Papermage lambda service with parallel processing support
- Cosmos literature pdf processing service with extraction of paper text, table, plot, diagrams and equation images

For the equation extraction (image to latex), we have the following:
- GPT4V equation extraction service
- SKEMA equation extraction service (low accuracy)



